@@ -1,22 +1,28 @@
 import logging
 import time
-from threading import Event
+from asyncio import Event
 from typing import Union, List, Any, Optional
 
-from pyobs.interfaces.proxies import IMotionProxy
+from pyobs.interfaces import IMotion
 from pyobs.modules import Module
 from pyobs.utils.enums import MotionStatus
+from pyobs.utils.parallel import event_wait
 
 log = logging.getLogger(__name__)
 
 
 class WaitForMotionMixin:
     """Mixin for a device that should wait for the motion status of another device."""
-    __module__ = 'pyobs.mixins'
 
-    def __init__(self, wait_for_modules: Optional[List[str]] = None,
-                 wait_for_states: Optional[List[Union[MotionStatus, str]]] = None,
-                 wait_for_timeout: float = 0, **kwargs: Any):
+    __module__ = "pyobs.mixins"
+
+    def __init__(
+        self,
+        wait_for_modules: Optional[List[str]] = None,
+        wait_for_states: Optional[List[Union[MotionStatus, str]]] = None,
+        wait_for_timeout: float = 0,
+        **kwargs: Any,
+    ):
         """Initializes the mixin.
 
         Args:
@@ -27,11 +33,14 @@ class WaitForMotionMixin:
 
         # store
         self.__wait_for_modules = wait_for_modules if wait_for_modules is not None else []
-        self.__wait_for_states = [s if isinstance(s, MotionStatus) else MotionStatus(s)
-                                  for s in wait_for_states] if wait_for_states is not None else []
+        self.__wait_for_states = (
+            [s if isinstance(s, MotionStatus) else MotionStatus(s) for s in wait_for_states]
+            if wait_for_states is not None
+            else []
+        )
         self.__wait_for_timeout = wait_for_timeout
 
-    def _wait_for_motion(self, abort: Event) -> None:
+    async def _wait_for_motion(self, abort: Event) -> None:
         """Wait until all devices are in one of the given motion states.
 
         Args:
@@ -48,36 +57,36 @@ class WaitForMotionMixin:
         # check type
         this = self
         if not isinstance(self, Module):
-            raise ValueError('This is not a module.')
+            raise ValueError("This is not a module.")
 
         # get all proxies
-        proxies = [self.proxy(device) for device in this.__wait_for_modules]
+        proxies = [await self.proxy(device) for device in this.__wait_for_modules]
 
         # all need to be derived from IMotion
-        if not all([isinstance(p, IMotionProxy) for p in proxies]):
-            raise ValueError('Not all given devices are derived from IMotionProxy!')
+        if not all([isinstance(p, IMotion) for p in proxies]):
+            raise ValueError("Not all given devices are derived from IMotion!")
 
         # run until timeout
         start = time.time()
-        log.info('Waiting for motion of other modules...')
+        log.info("Waiting for motion of other modules...")
         while not abort.is_set():
             # timeout?
             if time.time() > start + this.__wait_for_timeout:
                 raise TimeoutError
 
             # get all states and compare them
-            states = [p.get_motion_status().wait() for p in proxies]
+            states = [await p.get_motion_status() for p in proxies]
 
             # in a good state?
             good = [s in this.__wait_for_states for s in states]
 
             # if all good, we're finished waiting
             if all(good):
-                log.info('All other modules have finished moving.')
+                log.info("All other modules have finished moving.")
                 break
 
             # sleep a little
-            abort.wait(1)
+            await event_wait(abort, 1)
 
 
-__all__ = ['WaitForMotionMixin']
+__all__ = ["WaitForMotionMixin"]
